<?php

/*
 * LMS version 1.6.1 Ishta
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: tariffmove.php,v 1.20.2.1 2005/05/13 20:10:07 alec Exp $
 */

if($LMS->TariffExists($_GET['from']) && $LMS->TariffExists($_GET['to']) && $_GET['is_sure'] = 1)
{
	$LMS->TariffMove($_GET['from'],$_GET['to']);
	$SESSION->redirect('?m=tariffinfo&id='.$_GET['to']);
}
else
	header("Location: ?".$SESSION->get('backto'));

?>
